@@ -6,7 +6,13 @@ use base 'AnyEvent::DNS';
 
 use Data::Dumper;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
+
+# Detect AnyEvent >= 6.0.1
+my $IS_AE_6X = version->parse(AnyEvent->VERSION()) >= version->parse('v6.0.1');
+
+# Default TTL for AnyEvent < 6.0.1
+my $DEFAULT_TTL = undef;
 
 sub import {
 	my $package = shift;
@@ -33,18 +39,37 @@ sub resolve {
 		return;
 	}
 
-	# Performe a request and cache the value
+	# Perform a request and cache the value
 	$self->SUPER::resolve(
 		$qname,
 		$qtype,
 		%opt,
 		sub{
-			# Note that it could be possible that the multiple DNS request are
-			# done a new qname. For instance if an application is doing multiple
+			# Note that it could be possible that multiple DNS request are done
+			# for a new qname. For instance if an application is doing multiple
 			# concurrent HTTP request to the same host then there will be at
 			# least one DNS request per HTTP request. That's why we only cache
 			# the results of the first DNS request that's successful.
 			$cache->{$qname} ||= @_ ? $_[0] : undef;
+
+			# Respect TTL and be backwards compatible with AnyEvent < 6.x
+			my $ttl;
+			if ($IS_AE_6X) {
+				$ttl = defined $DEFAULT_TTL ? $DEFAULT_TTL : int($_[0]->[3] || 0);
+			}
+			else {
+				$ttl = defined $DEFAULT_TTL ? $DEFAULT_TTL : 0;
+			}
+
+			if ($ttl > 0) {
+				# Create expire timer
+				my $wt;
+				$wt  = AE::timer($ttl, 0, sub {
+					$wt = undef;
+					delete($cache->{$qname});
+				});
+			}
+
 			$cb->(@_);
 		}
 	);
@@ -71,6 +96,8 @@ sub register {
 		$resolver->os_config();
 	}
 
+	$DEFAULT_TTL = abs(int($ENV{PERL_ANYEVENT_DNS_TTL} || 0)) if exists $ENV{PERL_ANYEVENT_DNS_TTL};
+
 	$AnyEvent::DNS::RESOLVER = $resolver;
 }
 
@@ -110,6 +137,37 @@ passing the tag C<:register> in the C<use> statement.
 
 Registers a new DNS cache instance as AnyEvent's global DNS resolver.
 
+=head2  ENVIRONMENT
+
+=over
+
+=item C<PERL_ANYEVENT_DNS_TTL>
+
+The effect of setting this variable differs depending on L<AnyEvent> version.
+
+=over
+
+=item AnyEvent 5.x
+
+Default DNS response record cache TTL for older AnyEvent versions.
+L<AnyEvent::DNS> <= 6.x doesn't report record TTL and records get
+cached for infinite amount of time, therefore running programs won't
+detect if cached DNS records have changed.
+
+B<NOTE>: Setting this variable to C<0> disables purging records from
+cache.
+
+=item AnyEvent 6.x
+
+Newer versions of AnyEvent report DNS record TTL so records will be
+purged from the cache after B<their> TTL expires. Setting this variable to any
+positive integer B<OVERRIDES> the TTL for all records to the specified
+value, setting variable to C<0> disables purging records from the cache.
+
+=back
+
+=back
+
 =head1 AUTHOR
 
 Emmanuel Rodriguez <potyl@cpan.org>
